@@ -7,11 +7,12 @@ import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase, with_transaction
 from trytond.pool import Pool
 
-from trytond.modules.company.tests import create_company, set_company
+from trytond.modules.company.tests import (
+    create_company, set_company, CompanyTestMixin)
 from trytond.modules.account.tests import create_chart
 
 
-class StockSupplyDayTestCase(ModuleTestCase):
+class StockSupplyDayTestCase(CompanyTestMixin, ModuleTestCase):
     'Test StockSupplyDay module'
     module = 'stock_supply_day'
 
@@ -104,6 +105,7 @@ class StockSupplyDayTestCase(ModuleTestCase):
         Account = pool.get('account.account')
         ProductSupplier = pool.get('purchase.product_supplier')
         ProductSupplierDay = pool.get('purchase.product_supplier.day')
+        Day = pool.get('ir.calendar.day')
 
         uom_category, = UomCategory.create([{'name': 'Test'}])
         uom, = Uom.create([{
@@ -125,11 +127,11 @@ class StockSupplyDayTestCase(ModuleTestCase):
         with set_company(company):
             create_chart(company)
             receivable, = Account.search([
-                ('kind', '=', 'receivable'),
+                ('type.receivable', '=', True),
                 ('company', '=', company.id),
                 ])
             payable, = Account.search([
-                ('kind', '=', 'payable'),
+                ('type.payable', '=', True),
                 ('company', '=', company.id),
                 ])
             supplier, = Party.create([{
@@ -138,15 +140,16 @@ class StockSupplyDayTestCase(ModuleTestCase):
                         'account_payable': payable.id,
                         }])
             product_supplier, = ProductSupplier.create([{
-                        'product': template.id,
+                        'template': template.id,
                         'company': company.id,
                         'party': supplier.id,
                         'lead_time': lead_time,
                         }])
             if weekday is not None:
+                day, = Day.search([('index', '=', weekday)])
                 ProductSupplierDay.create([{
                             'product_supplier': product_supplier.id,
-                            'weekday': str(weekday),
+                            'day': day.id,
                             }])
             return product_supplier
 
